.. _api_ref:

.. currentmodule:: neurolang

User Guide
==========

End-User Frontend
-----------------

.. autosummary::
   :toctree: gen_api
   :nosignatures:

    NeurolangDL
    NeurolangPDL

Intermediate Representation Infrastructure
------------------------------------------

.. autosummary::
   :toctree: gen_api
  
   expressions
   expression_pattern_matching
   expression_walker
   exceptions


Intermediate Language Representations
-------------------------------------

.. autosummary::
   :toctree: gen_api
    
   logic
   datalog
   probabilistic
   relational_algebra
   relational_algebra_provenance 


Indices and tables
------------------
* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
